@@ -68,5 +68,12 @@ hashDescr _ = error "Hash problem" -- FIXME
 
 pubkeyToMPIs :: PKey -> [MPI]
 pubkeyToMPIs (RSAPubKey k) = [MPI (RSA.public_n k), MPI (RSA.public_e k)]
-pubkeyToMPIs (DSAPubKey k) = (\(p,g,q) y -> [MPI p,MPI q,MPI g,MPI y]) (DSA.public_params k) (DSA.public_y k)
+pubkeyToMPIs (DSAPubKey k) = [
+                               pkParams DSA.params_p
+                             , pkParams DSA.params_q
+                             , pkParams DSA.params_g
+                             , MPI . DSA.public_y $ k
+			     ]
+  where pkParams f = MPI . f . DSA.public_params $ k
+
 pubkeyToMPIs (ElGamalPubKey k) = fmap MPI k
