@@ -8,6 +8,7 @@ module Codec.Encryption.OpenPGP.Serialize (
 ) where
 
 import Control.Applicative ((<$>),(<*>))
+import Control.Lens ((^.))
 import Control.Monad (guard, mplus, replicateM)
 import qualified Crypto.PubKey.RSA as R
 import qualified Crypto.PubKey.DSA as D
@@ -750,18 +751,18 @@ getPubkey :: PubKeyAlgorithm -> Get PKey
 getPubkey RSA = do MPI n <- get
                    MPI e <- get
                    return $ RSAPubKey (R.PublicKey (B.length . integerToBEBS $ n) n e)
-getPubkey RSAEncryptOnly = getPubkey RSA
-getPubkey RSASignOnly = getPubkey RSA
+getPubkey DeprecatedRSAEncryptOnly = getPubkey RSA
+getPubkey DeprecatedRSASignOnly = getPubkey RSA
 getPubkey DSA = do MPI p <- get
                    MPI q <- get
                    MPI g <- get
                    MPI y <- get
                    return $ DSAPubKey (D.PublicKey (D.Params p g q) y)
-getPubkey ElgamalEncryptOnly = getPubkey Elgamal
-getPubkey Elgamal = do MPI p <- get
-                       MPI g <- get
-                       MPI y <- get
-                       return $ ElGamalPubKey [p,g,y]
+getPubkey ElgamalEncryptOnly = getPubkey ForbiddenElgamal
+getPubkey ForbiddenElgamal = do MPI p <- get
+                                MPI g <- get
+                                MPI y <- get
+                                return $ ElGamalPubKey [p,g,y]
 getPubkey t = fail ("Unsupported pubkey type " ++ show t)
 
 putPubkey :: PKey -> Put
@@ -769,7 +770,7 @@ putPubkey p = mapM_ put (pubkeyToMPIs p)
 
 getSecretKey :: PKPayload -> Get SKey
 getSecretKey pkp
-    | _pkalgo pkp `elem` [RSA, RSAEncryptOnly, RSASignOnly] =
+    | _pkalgo pkp `elem` [RSA, DeprecatedRSAEncryptOnly, DeprecatedRSASignOnly] =
         do MPI d <- get
            MPI p <- get
            MPI q <- get
@@ -778,11 +779,11 @@ getSecretKey pkp
                dP = 0
                dQ = 0
                qinv = 0
-               pub = (\(RSAPubKey x) -> x) (_pubkey pkp)
+               pub = (\(RSAPubKey x) -> x) (pkp^.pubkey)
            return $ RSAPrivateKey (R.PrivateKey pub d p q dP dQ qinv)
     | _pkalgo pkp == DSA = do MPI x <- get
                               return $ DSAPrivateKey (D.PrivateKey (D.Params 0 0 0) x)
-    | _pkalgo pkp `elem` [ElgamalEncryptOnly,Elgamal] =
+    | _pkalgo pkp `elem` [ElgamalEncryptOnly,ForbiddenElgamal] =
         do MPI x <- get
            return $ ElGamalPrivateKey [x]
 
