@@ -15,6 +15,7 @@ module Codec.Encryption.OpenPGP.SerializeForSigs (
  , payloadForSig
 ) where
 
+import Control.Lens ((^.))
 import Data.ByteString (ByteString)
 import qualified Data.ByteString as B
 import qualified Data.ByteString.Char8 as BC8
@@ -100,7 +101,7 @@ putKeyForSigning' pkp = do
     putByteString bs
 
 payloadForSig :: SigType -> PktStreamContext -> ByteString
-payloadForSig BinarySig state = (\(LiteralDataPkt _ _ _ bs) -> bs) (lastLD state)
+payloadForSig BinarySig state = (fromPkt (lastLD state))^.literalDataPayload
 payloadForSig CanonicalTextSig state = payloadForSig BinarySig state
 payloadForSig StandaloneSig _ = B.empty
 payloadForSig GenericCert state = kandUPayload (lastPrimaryKey state) (lastUIDorUAt state)
