@@ -5,63 +5,7 @@
 
 {-# LANGUAGE DeriveDataTypeable, ExistentialQuantification, TemplateHaskell, TypeFamilies #-}
 
-module Codec.Encryption.OpenPGP.Types (
-   SigSubPacket(..)
- , SigSubPacketPayload(..)
- , CompressionAlgorithm(..)
- , HashAlgorithm(..)
- , PubKeyAlgorithm(..)
- , SymmetricAlgorithm(..)
- , MPI(..)
- , S2K(..)
- , SignaturePayload(..)
- , UserAttrSubPacket(..)
- , SigType(..)
- , ImageHeader(..)
- , ImageFormat(..)
- , KeyVersion(..)
- , PKPayload(..)
- , SKAddendum(..)
- , DataType(..)
- , PKey(..)
- , SKey(..)
- , EightOctetKeyId(..)
- , TwentyOctetFingerprint(..)
- , TK(..)
- , FutureFlag
- , FutureVal
- , Keyring
- , fromFVal
- , fromFFlag
- , toFVal
- , toFFlag
- , Block(Block)
- , unBlock
- , Pkt(..)
- , Packet
- , PKESK(..)
- , Signature(..)
- , SKESK(..)
- , OnePassSignature(..)
- , SecretKey(..)
- , PublicKey(..)
- , SecretSubkey(..)
- , CompressedData(..)
- , SymEncData(..)
- , Marker(..)
- , LiteralData(..)
- , Trust(..)
- , UserId(..)
- , PublicSubkey(..)
- , UserAttribute(..)
- , SymEncIntegrityProtectedData(..)
- , ModificationDetectionCode(..)
- , OtherPacket(..)
- , fromPkt
- , toPkt
- , Verification(..)
- , KeyFlag(..)
-) where
+module Codec.Encryption.OpenPGP.Types where
 
 import qualified Crypto.PubKey.RSA as RSA
 import qualified Crypto.PubKey.DSA as DSA
@@ -165,12 +109,12 @@ instance FutureFlag NotationFlag where
     toFFlag o = OtherNF (fromIntegral o)
 
 data SigSubPacket = SigSubPacket {
-    sspCriticality :: Bool
-  , sspPayload :: SigSubPacketPayload
+    _sspCriticality :: Bool
+  , _sspPayload :: SigSubPacketPayload
   } deriving (Data, Eq, Typeable)
 
 instance Show SigSubPacket where
-    show x = (if sspCriticality x then "*" else "") ++ (show . sspPayload) x
+    show x = (if _sspCriticality x then "*" else "") ++ (show . _sspPayload) x
 
 data SigSubPacketPayload = SigCreationTime TimeStamp
                   | SigExpirationTime TimeStamp
@@ -263,13 +207,13 @@ class (Eq a, Ord a) => FutureVal a where
    toFVal :: Word8 -> a
 
 data PubKeyAlgorithm = RSA
-                     | RSAEncryptOnly
-                     | RSASignOnly
+                     | DeprecatedRSAEncryptOnly
+                     | DeprecatedRSASignOnly
                      | ElgamalEncryptOnly
                      | DSA
                      | EC
                      | ECDSA
-                     | Elgamal
+                     | ForbiddenElgamal
                      | DH
                      | OtherPKA Word8
     deriving (Show, Data, Typeable)
@@ -282,23 +226,23 @@ instance Ord PubKeyAlgorithm where
 
 instance FutureVal PubKeyAlgorithm where
     fromFVal RSA = 1
-    fromFVal RSAEncryptOnly = 2
-    fromFVal RSASignOnly = 3
+    fromFVal DeprecatedRSAEncryptOnly = 2
+    fromFVal DeprecatedRSASignOnly = 3
     fromFVal ElgamalEncryptOnly = 16
     fromFVal DSA = 17
     fromFVal EC = 18
     fromFVal ECDSA = 19
-    fromFVal Elgamal = 20
+    fromFVal ForbiddenElgamal = 20
     fromFVal DH = 21
     fromFVal (OtherPKA o) = o
     toFVal 1 = RSA
-    toFVal 2 = RSAEncryptOnly
-    toFVal 3 = RSASignOnly
+    toFVal 2 = DeprecatedRSAEncryptOnly
+    toFVal 3 = DeprecatedRSASignOnly
     toFVal 16 = ElgamalEncryptOnly
     toFVal 17 = DSA
     toFVal 18 = EC
     toFVal 19 = ECDSA
-    toFVal 20 = Elgamal
+    toFVal 20 = ForbiddenElgamal
     toFVal 21 = DH
     toFVal o = OtherPKA o
 
@@ -865,3 +809,4 @@ $(makeLenses ''ModificationDetectionCode)
 $(makeLenses ''OtherPacket)
 $(makeLenses ''TK)
 $(makeLenses ''Verification)
+$(makeLenses ''SigSubPacket)
