@@ -1,5 +1,5 @@
 -- Compression.hs: OpenPGP (RFC4880) compression conduits
--- Copyright © 2012  Clint Adams
+-- Copyright © 2012-2013  Clint Adams
 -- This software is released under the terms of the ISC license.
 -- (See the LICENSE file).
 
@@ -14,10 +14,7 @@ import Data.Conduit
 import qualified Data.Conduit.List as CL
 
 conduitCompress :: MonadThrow m => CompressionAlgorithm -> Conduit Pkt m Pkt
-conduitCompress algo = conduitState [] push (close algo)
-    where
-        push state input = return $ StateProducing (input : state) []
-        close a state = return [compressPkts a state]
+conduitCompress algo = CL.consume >>= \ps -> yield (compressPkts algo ps)
 
 conduitDecompress :: MonadThrow m => Conduit Pkt m Pkt
 conduitDecompress = CL.concatMap decompressPkt
