@@ -12,7 +12,7 @@ import Data.Time.Clock (UTCTime)
 
 import Codec.Encryption.OpenPGP.Internal (PktStreamContext(..), emptyPSC)
 import Codec.Encryption.OpenPGP.Types
-import Codec.Encryption.OpenPGP.Verify (verifySig)
+import Codec.Encryption.OpenPGP.Signatures (verifySig)
 import qualified Data.Conduit.List as CL
 
 conduitVerify :: MonadResource m => Keyring -> Maybe UTCTime -> Conduit Pkt m (Either String Verification)
